#
# spec file for package python3-Sphinx
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Sphinx
Version:        1.3.1
Release:        3.6
Url:            http://sphinx.pocoo.org
Summary:        Python documentation generator
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/S/Sphinx/Sphinx-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Documentation requirements:
BuildRequires:  python3-Babel
BuildRequires:  python3-Jinja2 >= 2.3
BuildRequires:  python3-alabaster
BuildRequires:  python3-docutils >= 0.7
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-six
BuildRequires:  python3-snowballstemmer
BuildRequires:  python3-sphinx_rtd_theme
# Testsuite requirements:
BuildRequires:  python3-Pygments >= 1.2
BuildRequires:  python3-nose
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python3-Babel
Requires:       python3-Jinja2 >= 2.3
Requires:       python3-Pygments >= 2.0
Requires:       python3-alabaster
Requires:       python3-docutils >= 0.11
Requires:       python3-setuptools
Requires:       python3-six
Requires:       python3-snowballstemmer
Requires:       python3-sphinx_rtd_theme
Recommends:     python3-rst2pdf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of multiple
reStructuredText sources), written by Georg Brandl.  It was originally created
for the new Python documentation, and has excellent facilities for Python
project documentation, but C/C++ is supported as well, and more languages are
planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths
come from the power and straightforwardness of reStructuredText and its parsing
and translating suite, the Docutils.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description    doc
Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of multiple
reStructuredText sources), written by Georg Brandl.  It was originally created
for the new Python documentation, and has excellent facilities for Python
project documentation, but C/C++ is supported as well, and more languages are
planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths
come from the power and straightforwardness of reStructuredText and its parsing
and translating suite, the Docutils.

%prep
%setup -q -n Sphinx-%{version}
sed -i '/#\!/d' sphinx/pycode/pgen2/token.py # Fix non-excutable-script warning
# Add Interpreter version suffix to entrypoints (and thus /usr/bin binaries) to
# allow for update-alternatives later on:
sed -i "s|\(sphinx-.*\) =|\1-%{py3_ver} =|" setup.py # Add Python version suffix to binaries 
# Fix wrong end-of-line encoding
sed -i 's/\r$//' sphinx/themes/basic/static/jquery.js

%build
python3 setup.py build
python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo
python3 setup.py build_sphinx -b man

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for B in apidoc autogen build quickstart ; do
  touch %{buildroot}%{_sysconfdir}/alternatives/sphinx-$B
  ln -sf %{_sysconfdir}/alternatives/sphinx-$B %{buildroot}/%{_bindir}/sphinx-$B
done
install -d %{buildroot}%{_mandir}/man1/
for M in all apidoc build quickstart ; do
  install -m 644 build/sphinx/man/sphinx-$M.1 %{buildroot}%{_mandir}/man1/sphinx-$M-%{py3_ver}.1
  touch %{buildroot}%{_sysconfdir}/alternatives/sphinx-$M.1.gz
  ln -sf %{_sysconfdir}/alternatives/sphinx-$M.1.gz %{buildroot}%{_mandir}/man1/sphinx-$M.1.gz
done
%find_lang sphinx

%check
export LC_ALL=en_US.utf8
PYTHON=python3 make test

%post
update-alternatives \
    --install %{_bindir}/sphinx-apidoc sphinx-apidoc %{_bindir}/sphinx-apidoc-%{py3_ver} 30 \
    --slave %{_bindir}/sphinx-build sphinx-build %{_bindir}/sphinx-build-%{py3_ver} \
    --slave %{_bindir}/sphinx-autogen sphinx-autogen %{_bindir}/sphinx-autogen-%{py3_ver} \
    --slave %{_bindir}/sphinx-quickstart sphinx-quickstart %{_bindir}/sphinx-quickstart-%{py3_ver} \
    --slave %{_mandir}/man1/sphinx-all.1.gz sphinx-all.1 %{_mandir}/man1/sphinx-all-%{py3_ver}.1.gz \
    --slave %{_mandir}/man1/sphinx-apidoc.1.gz sphinx-apidoc.1 %{_mandir}/man1/sphinx-apidoc-%{py3_ver}.1.gz \
    --slave %{_mandir}/man1/sphinx-build.1.gz sphinx-build.1 %{_mandir}/man1/sphinx-build-%{py3_ver}.1.gz \
    --slave %{_mandir}/man1/sphinx-quickstart.1.gz sphinx-quickstart.1 %{_mandir}/man1/sphinx-quickstart-%{py3_ver}.1.gz \

%postun
if [ $1 -eq 0 ] ; then
  update-alternatives --remove sphinx-build %{_bindir}/sphinx-apidoc-%{py3_ver}
fi

%files -f sphinx.lang
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE README.rst
%{_bindir}/sphinx-apidoc
%{_bindir}/sphinx-apidoc-%{py3_ver}
%{_bindir}/sphinx-autogen
%{_bindir}/sphinx-autogen-%{py3_ver}
%{_bindir}/sphinx-build
%{_bindir}/sphinx-build-%{py3_ver}
%{_bindir}/sphinx-quickstart
%{_bindir}/sphinx-quickstart-%{py3_ver}
%{_mandir}/man1/sphinx-all.1.gz
%{_mandir}/man1/sphinx-all-%{py3_ver}.1.gz
%{_mandir}/man1/sphinx-apidoc.1.gz
%{_mandir}/man1/sphinx-apidoc-%{py3_ver}.1.gz
%{_mandir}/man1/sphinx-build.1.gz
%{_mandir}/man1/sphinx-build-%{py3_ver}.1.gz
%{_mandir}/man1/sphinx-quickstart.1.gz
%{_mandir}/man1/sphinx-quickstart-%{py3_ver}.1.gz
%{python3_sitelib}/sphinx/
%{python3_sitelib}/Sphinx-%{version}-py%{py3_ver}.egg-info
%ghost %{_sysconfdir}/alternatives/sphinx-apidoc
%ghost %{_sysconfdir}/alternatives/sphinx-autogen
%ghost %{_sysconfdir}/alternatives/sphinx-build
%ghost %{_sysconfdir}/alternatives/sphinx-quickstart
%ghost %{_sysconfdir}/alternatives/sphinx-all.1.gz
%ghost %{_sysconfdir}/alternatives/sphinx-apidoc.1.gz
%ghost %{_sysconfdir}/alternatives/sphinx-build.1.gz
%ghost %{_sysconfdir}/alternatives/sphinx-quickstart.1.gz

%files doc
%defattr(-,root,root,-)
%doc EXAMPLES build/sphinx/html

%changelog
* Mon Jun 29 2015 toddrme2178@gmail.com
- Added python-six as a requirement, not only as build requirement
- Update to 1.3.1
  + Bugs fixed
  * see http://sphinx-doc.org/changes.html#release-1-3-1-released-mar-17-2015
    for complete list of fixed bugs
- additional dependencies required by 1.3.1
  + python-Babel
  + python-alabaster
  + python-snowballstemmer
  + python-sphinx_rtdtheme
  + python-mock
  + python-six
- Update to 1.3
  + Incompatible changes
  * Roles ref, term and menusel now don’t generate emphasis nodes
    anymore. If you want to keep italic style, adapt your stylesheet.
  * Role numref uses %%s as special character to indicate position of
    figure numbers instead # symbol.
  * Dependency requirement updates: docutils 0.11, Pygments 2.0
  * The gettext_enables config value has been renamed to
    gettext_additional_targets.
  * #1735: Use https://doc.python.org/ instead of http protocol. It was
    used for sphinx.ext.intersphinx and some documentation.
  * update bundled ez_setup.py for setuptools-7.0 that requires Python
    2.6 or later.
  * Dropped support for Python 2.5, 3.1 and 3.2.
  * Dropped support for docutils versions up to 0.9.
  * Removed the sphinx.ext.oldcmarkup extension.
  * The deprecated config values exclude_trees, exclude_dirnames and
    unused_docs have been removed.
  * A new node, sphinx.addnodes.literal_strong, has been added, for text
    that should appear literally (i.e. no smart quotes) in strong
    font. Custom writers will have to be adapted to handle this node.
  * PR#269, #1476: replace <tt> tag by <code>. User customized
    stylesheets should be updated If the css contain some styles for tt>
    tag. Thanks to Takeshi Komiya.
  * #1543: templates_path is automatically added to exclude_patterns to
    avoid reading autosummary rst templates in the templates directory.
  * Custom domains should implement the new Domain.resolve_any_xref
    method to make the any role work properly.
  * gettext builder: gettext doesn’t emit uuid information to generated
    pot files by default. Please set True to gettext_uuid to emit uuid
    information. Additionally, if the python-levenshtein 3rd-party package is
    installed, it will improve the calculation time.
  * gettext builder: disable extracting/apply ‘index’ node by
    default. Please set ‘index’ to gettext_enables to enable extracting index
    entries.
  * PR#307: Add frame to code-block in LaTeX. Thanks to Takeshi Komiya.
  + Features added
  * Add convenience directives and roles to the C++ domain: directive
    cpp:var as alias for cpp:member, role :cpp:var as alias for :cpp:member,
    and role any for cross-reference to any C++ declaraction. #1577, #1744
  * The source_suffix config value can now be a list of multiple suffixes.
  * Add the ability to specify source parsers by source suffix with the
    source_parsers config value.
  * #1675: A new builder, AppleHelpBuilder, has been added that builds
    Apple Help Books.
  * #1346: Add new default theme;
    Add ‘alabaster’ theme.
    Add ‘sphinx_rtd_theme’ theme.
    The ‘default’ html theme has been renamed to ‘classic’. ‘default’
    is still available, however it will emit notice a recommendation that
    using new ‘alabaster’ theme.
  * Added highlight_options configuration value.
  * The language config value is now available in the HTML templates.
  * The env-updated event can now return a value, which is interpreted as
    an iterable of additional docnames that need to be rewritten.
  * #772: Support for scoped and unscoped enums in C++. Enumerators in
    unscoped enums are injected into the parent scope in addition to the enum
    scope.
  * Add todo_include_todos config option to quickstart conf file, handled
    as described in documentation.
  * HTML breadcrumb items tag has class “nav-item” and “nav-item-N” (like
    nav-item-0, 1, 2...).
  * New option sphinx-quickstart --use-make-mode for generating Makefile
    that use sphinx-build make-mode.
  * #1235: i18n: several node can be translated if it is set to
    gettext_additional_targets in conf.py. Supported nodes are:
    ‘literal-block’
    ‘doctest-block’
    ‘raw’
    ‘image’
  * #1227: Add html_scaled_image_link config option to conf.py, to
    control scaled image link.
  * #1597: Added possibility to return a new template name from
    html-page-context.
  * PR#314, #1150: Configuration values are now checked for their type. A
    warning is raised if the configured and the default value do not have the
    same type and do not share a common non-trivial base class.
  * Add support for Python 3.4.
  * Add support for docutils 0.12
  * Added sphinx.ext.napoleon extension for NumPy and Google style
    docstring support.
  * Added support for parallel reading (parsing) of source files with the
    sphinx-build -j option. Third-party extensions will need to be checked
    for compatibility and may need to be adapted if they store information in
    the build environment object. See env-merge-info.
  * Added the any role that can be used to find a cross-reference of any
    type in any domain. Custom domains should implement the new
    Domain.resolve_any_xref method to make this work properly.
  * Exception logs now contain the last 10 messages emitted by Sphinx.
  * Added support for extension versions (a string returned by setup(),
    these can be shown in the traceback log files). Version requirements for
    extensions can be specified in projects using the new needs_extensions
    config value.
  * Changing the default role within a document with the default-role
    directive is now supported.
  * PR#214: Added stemming support for 14 languages, so that the built-in
    document search can now handle these. Thanks to Shibukawa Yoshiki.
  * PR#296, PR#303, #76: numfig feature: Assign numbers to figures,
    tables and code-blocks. This feature is configured with numfig,
    numfig_secnum_depth and numfig_format. Also numref role is
    available. Thanks to Takeshi Komiya.
  * PR#202: Allow ”.” and “~” prefixed references in :param: doc fields
    for Python.
  * PR#184: Add autodoc_mock_imports, allowing to mock imports of
    external modules that need not be present when autodocumenting.
  * #925: Allow list-typed config values to be provided on the command
    line, like -D key=val1,val2.
  * #668: Allow line numbering of code-block and literalinclude
    directives to start at an arbitrary line number, with a new lineno-start
    option.
  * PR#172, PR#266: The code-block and literalinclude directives now can
    have a caption option that shows a filename before the code in the
    output. Thanks to Nasimul Haque, Takeshi Komiya.
  * Prompt for the document language in sphinx-quickstart.
  * PR#217: Added config values to suppress UUID and location information
    in generated gettext catalogs.
  * PR#236, #1456: apidoc: Add a -M option to put module documentation
    before submodule documentation. Thanks to Wes Turner and Luc Saffre.
  * #1434: Provide non-minified JS files for jquery.js and underscore.js
    to clarify the source of the minified files.
  * PR#252, #1291: Windows color console support. Thanks to meu31.
  * PR#255: When generating latex references, also insert latex
    target/anchor for the ids defined on the node. Thanks to Olivier
    Heurtier.
  * PR#229: Allow registration of other translators. Thanks to Russell
    Sim.
  * Add app.set_translator() API to register or override a Docutils
    translator class like html_translator_class.
  * PR#267, #1134: add ‘diff’ parameter to literalinclude. Thanks to
    Richard Wall and WAKAYAMA shirou.
  * PR#272: Added ‘bizstyle’ theme. Thanks to Shoji KUMAGAI.
  * Automatically compile *.mo files from *.po files when
    gettext_auto_build is True (default) and *.po is newer than *.mo file.
  * #623: sphinx.ext.viewcode supports imported function/class aliases.
  * PR#275: sphinx.ext.intersphinx supports multiple target for the
    inventory. Thanks to Brigitta Sipocz.
  * PR#261: Added the env-before-read-docs event that can be connected to
    modify the order of documents before they are read by the environment.
  * #1284: Program options documented with option can now start with +.
  * PR#291: The caption of code-block is recognised as a title of ref
    target. Thanks to Takeshi Komiya.
  * PR#298: Add new API: add_latex_package(). Thanks to Takeshi Komiya.
  * #1344: add gettext_enables to enable extracting ‘index’ to gettext
    catalog output / applying translation catalog to generated
    documentation.
  * PR#301, #1583: Allow the line numbering of the directive
    literalinclude to match that of the included file, using a new
    lineno-match option. Thanks to Jeppe Pihl.
  * PR#299: add various options to sphinx-quickstart. Quiet mode option
  - -quiet will skips wizard mode. Thanks to WAKAYAMA shirou.
  * #1623: Return types specified with :rtype: are now turned into links
    if possible.
  + Bugs fixed
  * see http://sphinx-doc.org/changes.html#release-1-3-released-mar-10-2015
    for complete list of fixed bugs
* Tue Sep  9 2014 toddrme2178@gmail.com
- Update to 1.2.3:
  + Features added
  * #1518: `sphinx-apidoc` command now have a `--version` option to show version
    information and exit
  * New locales: Hebrew, European Portuguese, Vietnamese.
  + Bugs fixed
  * #636: Keep straight single quotes in literal blocks in the LaTeX build.
  * #1419: Generated i18n sphinx.js files are missing message catalog entries
    from '.js_t' and '.html'. The issue was introduced from Sphinx-1.1
  * #1363: Fix i18n: missing python domain's cross-references with currentmodule
    directive or currentclass directive.
  * #1444: autosummary does not create the description from attributes docstring.
  * #1457: In python3 environment, make linkcheck cause "Can't convert 'bytes'
    object to str implicitly" error when link target url has a hash part.
    Thanks to Jorge_C.
  * #1467: Exception on Python3 if nonexistent method is specified by automethod
  * #1441: autosummary can't handle nested classes correctly.
  * #1499: With non-callable `setup` in a conf.py, now sphinx-build emits
    user-friendly error message.
  * #1502: In autodoc, fix display of parameter defaults containing backslashes.
  * #1226: autodoc, autosummary: importing setup.py by automodule will invoke
    setup process and execute `sys.exit()`. Now sphinx avoids SystemExit
    exception and emits warnings without unexpected termination.
  * #1503: py:function directive generate incorrectly signature when specifying
    a default parameter with an empty list `[]`. Thanks to Geert Jansen.
  * #1508: Non-ASCII filename raise exception on make singlehtml, latex, man,
    texinfo and changes.
  * #1531: On Python3 environment, docutils.conf with 'source_link=true' in the
    general section cause type error.
  * PR#270, #1533: Non-ASCII docstring cause UnicodeDecodeError when uses with
    inheritance-diagram directive. Thanks to WAKAYAMA shirou.
  * PR#281, PR#282, #1509: TODO extension not compatible with websupport. Thanks
    to Takeshi Komiya.
  * #1477: gettext does not extract nodes.line in a table or list.
  * #1544: `make text` generate wrong table when it has empty table cells.
  * #1522: Footnotes from table get displayed twice in LaTeX. This problem has
    been appeared from Sphinx-1.2.1 by #949.
  * #508: Sphinx every time exit with zero when is invoked from setup.py command.
    ex. `python setup.py build_sphinx -b doctest` return zero even if doctest
    failed.
- Update to 1.2.2:
  - PR#211: When checking for existence of the html_logo file, check the full
    relative path and not the basename.
  - PR#212: Fix traceback with autodoc and __init__ methods without docstring.
  - PR#213: Fix a missing import in the setup command.
  - #1357: Option names documented by option are now again allowed to not start
    with a dash or slash, and referencing them will work correctly.
  - #1358: Fix handling of image paths outside of the source directory when
    using the “wildcard” style reference.
  - #1374: Fix for autosummary generating overly-long summaries if first line
    doesn’t end with a period.
  - #1383: Fix Python 2.5 compatibility of sphinx-apidoc.
  - #1391: Actually prevent using “pngmath” and “mathjax” extensions at the
    same time in sphinx-quickstart.
  - #1386: Fix bug preventing more than one theme being added by the entry
    point mechanism.
  - #1370: Ignore “toctree” nodes in text writer, instead of raising.
  - #1364: Fix ‘make gettext’ fails when the ‘.. todolist::’ directive is
    present.
  - #1367: Fix a change of PR#96 that break
    sphinx.util.docfields.Field.make_field interface/behavior for item argument
    usage.
* Tue Jul 15 2014 toddrme2178@gmail.com
- Fix tests
* Fri Mar  7 2014 speilicke@suse.com
- Fix hardcoded python version typo
* Fri Feb 14 2014 speilicke@suse.com
- Drop junk files
* Mon Feb 10 2014 speilicke@suse.com
- Update to version 1.2.1
  + See CHANGES
- Fix update-alternatives usage
- Removed sphinx-setup_command_unicode.patch (upstream)
- Totally reworked the build, docs are now build from BUILDROOT as Sphinx
  has it's own way of invoken 2to3
- Dropped python3-Sphinx-docs.patch (not needed anymore)
* Tue Sep 24 2013 toddrme2178@gmail.com
- Add sphinx-docutils-0.10.patch
  Patch is already committed upstream, will be in release 1.2
  See:
  https://bitbucket.org/birkenfeld/sphinx/issue/998/docutils-010-will-break-sphinx-manpage
- Change suggests to recommends, suggests are not well supported
* Thu May 16 2013 speilicke@suse.com
- Fix update-alternatives and support upgrade from previous versions
* Tue May  7 2013 highwaystar.ru@gmail.com
- fix building under openSUSE 12.1, 12.2:
  BuildRequires: python3-2to3 should be explicitly stated
* Tue Apr 30 2013 speilicke@suse.com
- Apply update-alternatives for binaries and man-pages
* Tue Nov 20 2012 saschpe@suse.de
- Build and install man-pages
- Name Python3 binaries consistently:
  + Fix in setup.py to have correct egg-info data
* Tue Nov  6 2012 saschpe@suse.de
- Remove obsolete SUSE version checks
- Don't package locale files twice
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3-Sphinx package added
